@@ -385,7 +385,7 @@ def write_link_json(m, config):
 def write_about_json(m, config):
     with open(join(config.info_dir, 'about.json'), 'w') as fo:
         d = {}
-        for key in ('home', 'dev_url', 'doc_url', 'license_url',
+        for key in ('home', 'dev_url', 'doc_url', 'doc_source_url', 'license_url',
                     'license', 'summary', 'description', 'license_family'):
             value = m.get_value('about/%s' % key)
             if value:
@@ -616,6 +616,12 @@ def create_info_files_json_v1(m, info_dir, prefix, files, files_with_prefix):
 def get_build_index(config, clear_cache=True):
     # priority: local by croot (can vary), then channels passed as args,
     #     then channels from config.
+    native_dirs = [os.path.join(config.croot, dirname) for dirname in (config.subdir, 'noarch')]
+    for dirname in native_dirs:
+        if not os.path.isdir(dirname):
+            os.makedirs(dirname)
+        if not os.path.isfile(os.path.join(dirname, 'repodata.json.bz2')):
+            update_index(dirname, config)
     urls = [url_path(config.croot)] + list(config.channel_urls)
     index = get_index(channel_urls=urls,
                       prepend=not config.override_channels,
@@ -662,18 +668,7 @@ def create_env(prefix, specs, config, clear_cache=True, retry=0):
                 locks = []
                 try:
                     if config.locking:
-                        _pkgs_dirs = pkgs_dirs[:1]
-                        locked_folders = _pkgs_dirs + list(config.bldpkgs_dirs)
-                        for folder in locked_folders:
-                            if not os.path.isdir(folder):
-                                os.makedirs(folder)
-                            lock = utils.get_lock(folder, timeout=config.timeout)
-                            if not folder.endswith('pkgs'):
-                                update_index(folder, config=config, lock=lock,
-                                             could_be_mirror=False)
-                            locks.append(lock)
-                        # lock used to generally indicate a conda operation occurring
-                        locks.append(utils.get_lock('conda-operation', timeout=config.timeout))
+                        locks = utils.get_conda_operation_locks(config)
 
                     with utils.try_acquire_locks(locks, timeout=config.timeout):
                         index = get_build_index(config=config, clear_cache=True)
@@ -815,7 +810,8 @@ def post_process_files(m, initial_prefix_files):
     get_build_metadata(m, config=m.config)
     create_post_scripts(m, config=m.config)
 
-    # this is new-style noarch, with a value of 'python'
+    # this is new-style noarch, with a value of 'python'. We handle entry
+    # points for that at install time
     if not is_noarch_python(m):
         utils.create_entry_points(m.get_value('build/entry_points'), config=m.config)
     current_prefix_files = prefix_files(prefix=m.config.build_prefix)
@@ -863,7 +859,11 @@ can lead to packages that include their dependencies.""" % meta_files))
 def bundle_conda(output, metadata, config, env, **kw):
     log = logging.getLogger(__name__)
     log.info('Packaging %s', metadata.dist())
+
+    with utils.path_prepended(metadata.config.build_prefix):
+        env = environ.get_dict(config=metadata.config, m=metadata)
     files = output.get('files', [])
+
     if not files and output.get('script'):
         interpreter = output.get('script_interpreter')
         if not interpreter:
@@ -943,7 +943,9 @@ def bundle_conda(output, metadata, config, env, **kw):
         if os.path.isfile(final_output):
             os.remove(final_output)
         print(final_output)
-        utils.copy_into(tmp_path, final_output, config.timeout, locking=config.locking)
+        # disable locking here.  It's just a temp folder getting locked.  Removing it proved to be
+        #    a major bottleneck.
+        utils.copy_into(tmp_path, final_output, config.timeout, locking=False)
 
     update_index(os.path.dirname(output_folder), config=config)
 
@@ -1079,6 +1081,7 @@ def build(m, config, post=None, need_source_download=True, need_reparse_in_env=F
 
         utils.rm_rf(config.info_dir)
         files1 = prefix_files(prefix=config.build_prefix)
+
         for pat in m.always_include_files():
             has_matches = False
             for f in set(files1):
@@ -1140,6 +1143,7 @@ def build(m, config, post=None, need_source_download=True, need_reparse_in_env=F
                         cmd = [shell_path, '-x', '-e', work_file]
                         # this should raise if any problems occur while building
                         utils.check_call_env(cmd, env=env, cwd=src_dir)
+                        utils.remove_pycache_from_scripts(m.config.build_prefix)
 
     if post in [True, None]:
         with open(join(m.config.build_folder, 'prefix_files.txt'), 'r') as f:
@@ -1275,7 +1279,8 @@ def test(recipedir_or_package_or_metadata, config, move_broken=True):
 
     warn_on_use_of_SRC_DIR(metadata)
 
-    config.compute_build_id(metadata.name())
+    if config.set_build_id:
+        config.compute_build_id(metadata.name())
 
     clean_pkg_cache(metadata.dist(), config)
 
@@ -1406,7 +1411,8 @@ def test(recipedir_or_package_or_metadata, config, move_broken=True):
     try:
         utils.check_call_env(cmd, env=env, cwd=config.test_dir)
     except subprocess.CalledProcessError:
-        tests_failed(metadata, move_broken=move_broken, broken_dir=config.broken_dir, config=config)
+        tests_failed(recipedir_or_package_or_metadata, move_broken=move_broken,
+                     broken_dir=config.broken_dir, config=config)
 
     if need_cleanup:
         utils.rm_rf(recipe_dir)
@@ -1415,7 +1421,7 @@ def test(recipedir_or_package_or_metadata, config, move_broken=True):
     return True
 
 
-def tests_failed(m, move_broken, broken_dir, config):
+def tests_failed(package_or_metadata, move_broken, broken_dir, config):
     '''
     Causes conda to exit if any of the given package's tests failed.
 
@@ -1425,9 +1431,15 @@ def tests_failed(m, move_broken, broken_dir, config):
     if not isdir(broken_dir):
         os.makedirs(broken_dir)
 
+    if hasattr(package_or_metadata, 'config'):
+        pkg = bldpkg_path(package_or_metadata)
+    else:
+        pkg = package_or_metadata
+    dest = join(broken_dir, os.path.basename(pkg))
+
     if move_broken:
-        shutil.move(bldpkg_path(m), join(broken_dir, "%s.tar.bz2" % m.dist()))
-    sys.exit("TESTS FAILED: " + m.dist())
+        shutil.move(pkg, dest)
+    sys.exit("TESTS FAILED: " + os.path.basename(pkg))
 
 
 def check_external():
@@ -1556,6 +1568,10 @@ packages, the other package needs to be rebuilt
                                     .format(recipe) + error_str + "\n" + extra_help)
             retried_recipes.append(recipe)
             recipe_list.extendleft(add_recipes)
+        finally:
+            # clean up locks to avoid permission errors when they exist in central installs
+            for lock in utils.get_conda_operation_locks(metadata.config):
+                utils.rm_rf(lock.lock_file)
 
     if post in [True, None]:
         # TODO: could probably use a better check for pkg type than this...
@@ -1563,6 +1579,7 @@ packages, the other package needs to be rebuilt
         wheels = [f for f in built_packages if f.endswith('.whl')]
         handle_anaconda_upload(tarballs, config=config)
         handle_pypi_upload(wheels, config=config)
+
     return built_packages
 
 
@@ -1574,14 +1591,11 @@ def handle_anaconda_upload(paths, config):
     upload = False
     # this is the default, for no explicit argument.
     # remember that anaconda_upload takes defaults from condarc
-    if config.anaconda_upload is None:
-        pass
-    elif config.token or config.user:
+    if config.token or config.user:
         upload = True
     # rc file has uploading explicitly turned off
-    elif config.anaconda_upload is False:
+    elif not config.anaconda_upload:
         print("# Automatic uploading is disabled")
-        upload = False
     else:
         upload = True
 
@@ -1613,7 +1627,9 @@ Error: cannot locate anaconda command (required for upload)
 
     if config.token:
         cmd.extend(['--token', config.token])
-    cmd.extend(['upload', '--force'])
+    cmd.append('upload')
+    if config.force_upload:
+        cmd.append('--force')
     if config.user:
         cmd.extend(['--user', config.user])
     for package in paths:
