@@ -6,10 +6,19 @@ import os
 from os import lstat
 from pkg_resources import parse_version
 from enum import Enum
+from importlib import import_module
 
 from conda import __version__ as CONDA_VERSION
 
 
+def try_exports(module, attr):
+    # this assumes conda.exports exists, so only use for conda 4.3 onward
+    try:
+        return getattr(import_module('conda.exports'), attr)
+    except AttributeError:
+        return getattr(import_module(module), attr)
+
+
 try:
     # This monkey patch is addressed at #1825. The ensure_use_local is an outdated vestige
     #   and no longer has any relevant effect.
@@ -20,7 +29,11 @@ except ImportError:
     pass
 
 
-from conda.plan import display_actions, execute_actions, execute_plan, install_actions
+if parse_version(CONDA_VERSION) >= parse_version("4.4"):
+    from conda.exports import display_actions, execute_actions, execute_plan, install_actions
+else:
+    from conda.plan import display_actions, execute_actions, execute_plan, install_actions
+
 display_actions, execute_actions, execute_plan = display_actions, execute_actions, execute_plan
 install_actions = install_actions
 
@@ -143,6 +156,43 @@ else:
 EntityEncoder, FileMode, PathType = EntityEncoder, FileMode, PathType
 
 
+if parse_version(CONDA_VERSION) >= parse_version("4.3"):
+    CondaError = try_exports("conda.exceptions", "CondaError")
+    CondaHTTPError = try_exports("conda.exceptions", "CondaHTTPError")
+    LinkError = try_exports("conda.exceptions", "LinkError")
+    LockError = try_exports("conda.exceptions", "LockError")
+    NoPackagesFoundError = try_exports("conda.exceptions", "NoPackagesFoundError")
+    PaddingError = try_exports("conda.exceptions", "PaddingError")
+    UnsatisfiableError = try_exports("conda.exceptions", "UnsatisfiableError")
+
+    non_x86_linux_machines = try_exports("conda.base.context", "non_x86_linux_machines")
+    context = try_exports("conda.base.context", "context")
+    context_get_prefix = try_exports("conda.base.context", "get_prefix")
+    reset_context = try_exports("conda.base.context", "reset_context")
+    get_conda_build_local_url = try_exports("conda.models.channel", "get_conda_build_local_url")
+
+    binstar_upload = context.binstar_upload
+    bits = context.bits
+    conda_private = context.conda_private
+    default_python = context.default_python
+    envs_dirs = context.envs_dirs
+    pkgs_dirs = list(context.pkgs_dirs)
+    cc_platform = context.platform
+    root_dir = context.root_dir
+    root_writable = context.root_writable
+    subdir = context.subdir
+
+    get_rc_urls = lambda: list(context.channels)
+    get_prefix = partial(context_get_prefix, context)
+    cc_conda_build = context.conda_build if hasattr(context, 'conda_build') else {}
+
+    # disallow softlinks.  This avoids a lot of dumb issues, at the potential cost of disk space.
+    os.environ[str('CONDA_ALLOW_SOFTLINKS')] = str('false')
+    reset_context()
+
+    get_local_urls = lambda: list(get_conda_build_local_url()) or []
+    arch_name = context.arch_name
+
 if parse_version(CONDA_VERSION) >= parse_version("4.2"):
     from conda.exceptions import (CondaError, CondaHTTPError, LinkError, LockError,
                                   NoPackagesFoundError, PaddingError, UnsatisfiableError)
