@@ -26,7 +26,8 @@ def create_files(dir_path, m, config):
     for fn in ensure_list(m.get_value('test/files', [])):
         has_files = True
         path = join(m.path, fn)
-        copy_into(path, join(dir_path, fn), config.timeout, locking=config.locking)
+        # disable locking to avoid locking a temporary directory (the extracted test folder)
+        copy_into(path, join(dir_path, fn), config.timeout, locking=False)
     # need to re-download source in order to do tests
     if m.get_value('test/source_files') and not isdir(config.work_dir):
         source.provide(m, config=config)
@@ -40,8 +41,9 @@ def create_files(dir_path, m, config):
             raise RuntimeError("Did not find any source_files for test with pattern %s", pattern)
         for f in files:
             try:
+                # disable locking to avoid locking a temporary directory (the extracted test folder)
                 copy_into(f, f.replace(config.work_dir, config.test_dir), config.timeout,
-                        locking=config.locking)
+                          locking=False)
             except OSError as e:
                 log = logging.getLogger(__name__)
                 log.warn("Failed to copy {0} into test files.  Error was: {1}".format(f, str(e)))
@@ -68,7 +70,8 @@ def create_shell_files(dir_path, m, config):
         name = "run_test{}".format(ext)
 
     if exists(join(m.path, name)):
-        copy_into(join(m.path, name), dir_path, config.timeout, locking=config.locking)
+        # disable locking to avoid locking a temporary directory (the extracted test folder)
+        copy_into(join(m.path, name), dir_path, config.timeout, locking=False)
         has_tests = True
 
     with open(join(dir_path, name), 'a') as f:
@@ -99,18 +102,18 @@ def _create_test_files(dir_path, m, ext, comment_char='# '):
 
     if os.path.isfile(test_file):
         with open(out_file, 'w') as fo:
-            fo.write("%s tests for %s (this is a generated file)\n" % (comment_char, m.dist()))
-            fo.write("print('===== testing package: %s =====')\n" % m.dist())
+            fo.write("%s tests for %s (this is a generated file);\n" % (comment_char, m.dist()))
+            fo.write("print('===== testing package: %s =====');\n" % m.dist())
 
             try:
                 with open(test_file) as fi:
-                    fo.write("print('running {0}')\n".format(name))
+                    fo.write("print('running {0}');\n".format(name))
                     fo.write("{0} --- {1} (begin) ---\n".format(comment_char, name))
                     fo.write(fi.read())
                     fo.write("{0} --- {1} (end) ---\n".format(comment_char, name))
             except AttributeError:
                 fo.write("# tests were not packaged with this module, and cannot be run\n")
-            fo.write("\nprint('===== %s OK =====')\n" % m.dist())
+            fo.write("\nprint('===== %s OK =====');\n" % m.dist())
 
     return (out_file, os.path.isfile(test_file) and os.path.basename(test_file) != 'no-file')
 
@@ -128,13 +131,12 @@ def create_py_files(dir_path, m):
     likely_non_python_pkg = likely_r_pkg or likely_lua_pkg or likely_perl_pkg
 
     if likely_non_python_pkg:
-        imports = ensure_list(m.get_value('test/imports', []))
-        for import_item in imports:
+        imports = []
+        for import_item in ensure_list(m.get_value('test/imports', [])):
             # add any imports specifically marked as python
             if (hasattr(import_item, 'keys') and 'lang' in import_item and
                     import_item['lang'] == 'python'):
-                imports = import_item['imports']
-                break
+                imports.extend(import_item['imports'])
     else:
         imports = ensure_list(m.get_value('test/imports', []))
         imports = [item for item in imports if (not hasattr(item, 'keys') or
