@@ -258,16 +258,17 @@ def conda_build_vars(prefix, config):
 
 
 def python_vars(config, prefix):
+    py_ver = get_py_ver(config)
     vars_ = {
             'CONDA_PY': str(config.CONDA_PY),
             'PY3K': str(config.PY3K),
-            'PY_VER': get_py_ver(config),
+            'PY_VER': py_ver,
+            'STDLIB_DIR': utils.get_stdlib_dir(prefix, py_ver),
+            'SP_DIR': utils.get_site_packages(prefix, py_ver),
             }
     if os.path.isfile(config.python_bin(prefix)):
         vars_.update({
             'PYTHON': config.python_bin(prefix),
-            'STDLIB_DIR': utils.get_stdlib_dir(prefix),
-            'SP_DIR': utils.get_site_packages(prefix),
         })
     # Only define these variables if '--numpy=X.Y' was provided,
     # otherwise any attempt to use them should be an error.
@@ -432,6 +433,10 @@ def windows_vars(prefix):
         'USERNAME': os.getenv('USERNAME'),
         'USERPROFILE': os.getenv('USERPROFILE'),
         'windir': os.getenv('windir'),
+        # CPU data, see https://github.com/conda/conda-build/issues/2064
+        'PROCESSOR_ARCHITEW6432': os.getenv('PROCESSOR_ARCHITEW6432'),
+        'PROCESSOR_ARCHITECTURE': os.getenv('PROCESSOR_ARCHITECTURE'),
+        'PROCESSOR_IDENTIFIER': os.getenv('PROCESSOR_IDENTIFIER'),
     }
 
 
@@ -464,7 +469,9 @@ def linux_vars(compiler_vars, prefix, config):
     if config.arch == 32:
         compiler_vars['CFLAGS'] += ' -m32'
         compiler_vars['CXXFLAGS'] += ' -m32'
-    return {}
+    return {
+        'DISPLAY': os.getenv('DISPLAY'),
+    }
 
 
 def system_vars(env_dict, prefix, config):
