@@ -28,6 +28,7 @@ from .conda_interface import md5_file, unix_path_to_win, win_path_to_unix
 from .conda_interface import PY3, iteritems
 from .conda_interface import root_dir
 from .conda_interface import string_types
+from .conda_interface import pkgs_dirs
 
 from conda_build.os_utils import external
 
@@ -161,7 +162,7 @@ def copy_into(src, dst, timeout=90, symlinks=False, lock=None, locking=True):
             log.warn('path %s is a broken symlink - ignoring copy', src)
             return
 
-        if not lock:
+        if not lock and locking:
             lock = get_lock(src_folder, timeout=timeout)
         locks = [lock] if locking else []
         with try_acquire_locks(locks, timeout):
@@ -172,7 +173,6 @@ def copy_into(src, dst, timeout=90, symlinks=False, lock=None, locking=True):
                     os.makedirs(dst_folder)
                 except OSError:
                     pass
-
             try:
                 _copy_with_shell_fallback(src, dst_fn)
             except shutil.Error:
@@ -238,9 +238,10 @@ def merge_tree(src, dst, symlinks=False, timeout=90, lock=None, locking=True):
         raise IOError("Can't merge {0} into {1}: file exists: "
                       "{2}".format(src, dst, existing[0]))
 
-    if not lock:
-        lock = get_lock(src, timeout=timeout)
+    locks = []
     if locking:
+        if not lock:
+            lock = get_lock(src, timeout=timeout)
         locks = [lock]
     with try_acquire_locks(locks, timeout):
         copytree(src, dst, symlinks=symlinks)
@@ -254,7 +255,7 @@ _lock_folders = (os.path.join(root_dir, 'locks'),
                  os.path.expanduser(os.path.join('~', '.conda_build_locks')))
 
 
-def get_lock(folder, timeout=90, filename=".conda_lock"):
+def get_lock(folder, timeout=90):
     global _locations
     try:
         location = os.path.abspath(os.path.normpath(folder))
@@ -285,6 +286,22 @@ def get_lock(folder, timeout=90, filename=".conda_lock"):
     return _locations[location]
 
 
+def get_conda_operation_locks(config=None):
+    locks = []
+    # locks enabled by default
+    if not config or config.locking:
+        _pkgs_dirs = pkgs_dirs[:1]
+        locked_folders = _pkgs_dirs + list(config.bldpkgs_dirs) if config else []
+        for folder in locked_folders:
+            if not os.path.isdir(folder):
+                os.makedirs(folder)
+            lock = get_lock(folder, timeout=config.timeout if config else 90)
+            locks.append(lock)
+        # lock used to generally indicate a conda operation occurring
+        locks.append(get_lock('conda-operation', timeout=config.timeout if config else 90))
+    return locks
+
+
 def relative(f, d='lib'):
     assert not f.startswith('/'), f
     assert not d.startswith('/'), d
@@ -480,25 +497,16 @@ def path2url(path):
     return urlparse.urljoin('file:', urllib.pathname2url(path))
 
 
-def get_stdlib_dir(prefix):
+def get_stdlib_dir(prefix, py_ver):
     if sys.platform == 'win32':
-        stdlib_dir = os.path.join(prefix, 'Lib')
+        lib_dir = os.path.join(prefix, 'Lib')
     else:
-        lib_dir = os.path.join(prefix, 'lib')
-        stdlib_dir = glob(os.path.join(lib_dir, 'python[0-9\.]*'))
-        if not stdlib_dir:
-            stdlib_dir = ''
-        else:
-            stdlib_dir = stdlib_dir[0]
-    return stdlib_dir
+        lib_dir = os.path.join(prefix, 'lib', 'python{}'.format(py_ver))
+    return lib_dir
 
 
-def get_site_packages(prefix):
-    stdlib_dir = get_stdlib_dir(prefix)
-    sp = ''
-    if stdlib_dir:
-        sp = os.path.join(stdlib_dir, 'site-packages')
-    return sp
+def get_site_packages(prefix, py_ver):
+    return os.path.join(get_stdlib_dir(prefix, py_ver), 'site-packages')
 
 
 def get_build_folders(croot):
@@ -752,3 +760,16 @@ def conda_43():
     """Conda 4.3 broke compatibility in lots of new fun and exciting ways.  This function is for
     changing conda-build's behavior when conda 4.3 or higher is installed."""
     return LooseVersion(conda_version) >= LooseVersion('4.3')
+
+
+def remove_pycache_from_scripts(build_prefix):
+    """Remove pip created pycache directory from bin or Scripts."""
+    if on_win:
+        scripts_path = os.path.join(build_prefix, 'Scripts')
+    else:
+        scripts_path = os.path.join(build_prefix, 'bin')
+
+    for entry in os.listdir(scripts_path):
+        entry_path = os.path.join(scripts_path, entry)
+        if os.path.isdir(entry_path) and entry.strip(os.sep) == '__pycache__':
+            shutil.rmtree(entry_path)
